@@ -12,7 +12,7 @@
 
 -- |
 -- Module      :  Test.ChasingBottoms.ContinuousFunctions
--- Copyright   :  (c) Nils Anders Danielsson 2005-2016
+-- Copyright   :  (c) Nils Anders Danielsson 2005-2017
 -- License     :  See the file LICENCE.
 --
 -- Maintainer  :  http://www.cse.chalmers.se/~nad/
@@ -148,6 +148,9 @@ import Test.QuickCheck
          , listOf
 #if MIN_VERSION_QuickCheck(2,7,0)
          , infiniteListOf
+#endif
+#if MIN_VERSION_QuickCheck(2,10,0)
+         , function
 #endif
          )
 #if MIN_VERSION_QuickCheck(2,7,0)
@@ -193,9 +196,8 @@ functionTo = function match
 -- | 'PatternMatch' packages up the possible outcomes of a pattern
 -- match in a style suitable for generating functions. A pattern match
 -- is a generator ('Gen') transformer based on the top-level
--- constructor, and a sequence (see
--- <http://www.soi.city.ac.uk/~ross/software/html/Data.Sequence.html>) of
--- 'PatternMatch'es based on the children of that constructor.
+-- constructor, and a sequence of 'PatternMatch'es based on the
+-- children of that constructor.
 
 data PatternMatch
   = PatternMatch { apply :: GenTransformer
