@@ -1,4 +1,5 @@
-{-# LANGUAGE ScopedTypeVariables, DeriveDataTypeable #-}
+{-# LANGUAGE CPP, DeriveDataTypeable, MonoLocalBinds, NamedFieldPuns,
+             ScopedTypeVariables #-}
 
 -- TODO: Tests passed even though for finiteTreeOf and finiteListOf
 -- transform was only applied once at the top-level!
@@ -73,34 +74,45 @@ depth (Branch l r)   = 1 + (depth l `max` depth r)
 --
 -- How do we test these properties?
 
+type DistributionTest = Int -> [(String, Double)] -> (Bool, String)
+
+testDistribution :: Testable a => DistributionTest -> a -> IO Bool
 testDistribution test t = do
   result <- run t
   let (ok, msg) = apply test result
   unless ok $ putStrLn msg
   return ok
   where
-  apply test Success{labels = labels} = test labels
-  apply _    _                        = (False, "Test failed.")
+#if MIN_VERSION_QuickCheck(2,10,0)
+  convert _        labels = labels
+#else
+  convert numTests labels =
+    map (\(x, f) -> (x, fromIntegral f / fromIntegral numTests)) labels
+#endif
 
-spread labels = (uniqueShare >= 3%4, "uniqueShare: " ++ show uniqueShare)
+  apply test Success{numTests, labels} = test numTests
+                                              (convert numTests labels)
+  apply _    _                         = (False, "Test failed.")
+
+spread :: DistributionTest
+spread numTests labels =
+  (uniqueShare >= 3%4, "uniqueShare: " ++ show uniqueShare)
   where
   noUniqueArgs = length labels
-  noArgs       = sum $ map snd labels
-  uniqueShare  = noUniqueArgs % noArgs
+  uniqueShare  = noUniqueArgs % numTests
 
-len max avg short labels =
-  ( maxLen >= max && averageLen >= avg && shortShare >= 1%10
+len :: Integer -> Double -> Integer -> DistributionTest
+len max avg short numTests labels =
+  ( maxLen >= max && averageLen >= avg && shortShare >= 0.1
   , "maxLen: " ++ show maxLen ++
     ", averageLen: " ++ show averageLen ++
     ", shortShare: " ++ show shortShare
   )
   where
-  lengths      = map (read *** toInteger) labels :: [(Integer, Integer)]
-  noArgs       = sum (map snd lengths)
-  maxLen       = maximum $ map fst lengths
-  averageLen   = sum (map (uncurry (*)) lengths) % noArgs
-  noShortLists = sum . map snd . filter ((<= short) . fst) $ lengths
-  shortShare   = noShortLists % noArgs
+  lengths    = map (read *** id) labels :: [(Integer, Double)]
+  maxLen     = maximum $ map fst lengths
+  averageLen = sum $ map (\(n, f) -> fromInteger n * f) lengths
+  shortShare = sum . map snd . filter ((<= short) . fst) $ lengths
 
 -- | We want to make sure that we can generate many different kinds of
 -- lazy functions.
@@ -184,9 +196,10 @@ tests = do
     theIOTests = []
 
     -- Disabled, because occasionally one or more of the tests failed,
-    -- and (at the time of writing in 2015) I have no interest in
-    -- fixing test suite bugs in old, unfinished and experimental
-    -- code. Known problems:
+    -- and (at the time of writing in 2015 and 2017) I have no
+    -- interest in fixing test suite bugs in old, unfinished and
+    -- experimental code. Known problems (in code that has later been
+    -- changed due to changes to QuickCheck):
     -- * Division by zero, presumably because noArgs is 0.
     -- * After reducing maxSuccess from 1000 to 100 I once observed
     --   that "averageLen" was 199 % 100, but if I am not mistaken the
