@@ -1,9 +1,10 @@
 {-# LANGUAGE ScopedTypeVariables, RankNTypes,
-             FlexibleInstances, UndecidableInstances #-}
+             FlexibleInstances, UndecidableInstances,
+             MonoLocalBinds #-}
 
 -- |
 -- Module      :  Test.ChasingBottoms.SemanticOrd
--- Copyright   :  (c) Nils Anders Danielsson 2004-2016
+-- Copyright   :  (c) Nils Anders Danielsson 2004-2017
 -- License     :  See the file LICENCE.
 --
 -- Maintainer  :  http://www.cse.chalmers.se/~nad/
